# dialog-workflow-local-python-package

TODO for the future to write program which validate the scripts and check there are always options for multi_choice_poll()<br>

TODO def get_dialog_workflow_profile_id( profile_id1, prompt: str, profile_id2 = None, group_id) -> int:
    # If profile_id2 == None or profile.id2 is Business Profile - Use avatar_table and avatar_group_table to determine who will answer.
    # Look on previous conversations
    # Look for relevant avatar profile_id for the profile_id1

TODO Add support to question

TODO Add support to multi queestion send to the client
